@@ -38,7 +38,7 @@
 #endif /* HAVE_DMALLOC_H */
 #include <sys/stat.h>
 
-#include <hash.h>
+#include <khash.h>
 #include <getopttools.h>
 #include <urldirname.h>
 #include <split.h>
@@ -1287,8 +1287,10 @@ static void mirror_cleanup(crawl_context_t* context)
       int hookid = row[2] ? atoi(row[2]) : 0;
       char* url = row[3];
 
-      if(hookid && context->params->hook)
-	context->params->hook->delete_id(context->params->hook, hookid, url, strlen(url));
+      if(hookid && context->params->hook) {
+	webbase_hook_params_t* hook = context->params->hook;
+	hook->delete_id(hook, hookid, url, strlen(url));
+      }
       sprintf(query, "delete from url where rowid = %d", rowid);
       smysql_query(&base->mysql, query);    
 #ifdef WEBBASE_CONTENT_BASE
@@ -1714,10 +1716,12 @@ static webbase_url_t* mirror_1(crawl_context_t* context, char* url)
   webbase_url_t* webbase_url = mirror_2(context, url);
 
   if(webbase_url) {
-    if(context->params->hook) {
+    webbase_hook_params_t* hook = context->params->hook;
+
+    if(hook) {
       char query[256];
       int hook_inserted = 0;
-      int hook_insert_now = context->params->hook->ok(context->params->hook, webbase_url);
+      int hook_insert_now = hook->ok(context->params->hook, webbase_url);
       int do_update = 0;
 
       /*
@@ -1733,12 +1737,12 @@ static webbase_url_t* mirror_1(crawl_context_t* context, char* url)
        */
       webbase_lock_ignore(context->base, webbase_url->w_rowid, "url");
       if(hook_inserted && hook_insert_now) 
-	context->params->hook->update(context->params->hook, webbase_url);
+	hook->update(hook, webbase_url);
       else if(hook_inserted && !hook_insert_now) {
-	context->params->hook->tdelete(context->params->hook, webbase_url);
+	hook->delete_id(hook, webbase_url->w_hookid, webbase_url->w_url, strlen(webbase_url->w_url));
 	do_update = 1;
       } else if(!hook_inserted && hook_insert_now) {
-	context->params->hook->insert(context->params->hook, webbase_url);
+	hook->insert(hook, webbase_url);
 	do_update = 1;
       } else
 	;
@@ -1878,6 +1882,15 @@ static webbase_url_t* mirror_2(crawl_context_t* context, char* url)
   if(context->no_crawl)
     return mirror_location(context, webbase_url);
 
+  /*
+   * Remember the previous content of the document for update/delete operations
+   */
+  if(context->params->hook) {
+    webbase_hook_params_t* hook = context->params->hook;
+
+    hook->prepare(hook, webbase_url->w_hookid, webbase_url->w_url, strlen(webbase_url->w_url));
+  }
+  
   /*
    * Robot exclusion compliance
    */
@@ -2539,7 +2552,7 @@ void crawl_free(crawl_params_t* params)
   dirsel_end();
   robots_free(params->robots);
   cookies_free(params->cookies);
-  hash_free(params->options);
+  _K(hash_free)(params->options);
   webbase_free(params->base);
   webtools_free(params->http);
   mirror_ftp_free();
