@@ -28,7 +28,7 @@
 #include <dmalloc.h>
 #endif /* HAVE_DMALLOC_H */
 
-#include <hash.h>
+#include <khash.h>
 #include <mime.h>
 #include <split.h>
 #include <strsubs.h>
