@@ -36,7 +36,7 @@
 #include <dmalloc.h>
 #endif /* HAVE_DMALLOC_H */
 
-#include <hash.h>
+#include <khash.h>
 #include <webbase.h>
 #include <salloc.h>
 #include <getopttools.h>
@@ -237,7 +237,7 @@ webbase_t* webbase_alloc(int argc, char** argv, struct option options[])
 
 void webbase_free(webbase_t* base)
 {
-  hash_free(base->options);
+  _K(hash_free)(base->options);
   mysql_close(&base->mysql);
   if(base->mysql_unix_port) free(base->mysql_unix_port);
   if(base->dir) free(base->dir);
