@@ -19,7 +19,7 @@
 #ifndef _webbase_h
 #define _webbase_h
 
-#include <hash.h>
+#include <khash.h>
 #include <webbase_url.h>
 #include <mysql.h>
 #include <uri.h>
